@@ -14,11 +14,15 @@
 #include "DebugEngine.h"
 #include "ExtraSocket.h"
 #include "cpp11addition.h"
+#include "FacilityEngine.h"
 
 #ifdef WIN32
 #	define __func__ __FUNCTION__
 #endif
 
+#ifdef ULTRACOPIER_DEBUGCONSOLE
+#undef ULTRACOPIER_DEBUGCONSOLE
+#endif
 /// \brief The local macro: ULTRACOPIER_DEBUGCONSOLE
 #if defined (__FILE__) && defined (__LINE__)
 #	define ULTRACOPIER_DEBUGCONSOLE(a,b) addDebugInformation(a,__func__,b,__FILE__,__LINE__)
@@ -59,7 +63,7 @@ DebugEngine::DebugEngine()
     debugHtmlContent+="</style>";
     debugHtmlContent+="<title>";
     debugHtmlContent+="Ultracopier";
-    debugHtmlContent+=" "+std::string(ULTRACOPIER_VERSION)+" "+ULTRACOPIER_PLATFORM_NAME.toStdString()+", debug report</title>";
+    debugHtmlContent+=" "+FacilityEngine::version()+" "+ULTRACOPIER_PLATFORM_NAME.toStdString()+", debug report</title>";
     debugHtmlContent+="</head>";
     debugHtmlContent+="<body>";
     debugHtmlContent+="<table>";
@@ -335,7 +339,7 @@ void DebugEngine::addDebugInformation(const DebugLevel_custom &level,const std::
         if(addDebugInformationCallNumber<ULTRACOPIER_DEBUG_MAX_GUI_LINE)
         {
             addDebugInformationCallNumber++;
-            DebugModel::debugModel->addDebugInformation(startTime.elapsed(),level,function,text,file,static_cast<const unsigned int>(ligne),location);
+            DebugModel::debugModel->addDebugInformation(startTime.elapsed(),level,function,text,file,static_cast<unsigned int>(ligne),location);
         }
     }
 }
