@@ -17,13 +17,17 @@ class InternetUpdater : public QObject
 public:
     explicit InternetUpdater(QObject *parent = 0);
     ~InternetUpdater();
+    void checkUpdate();
 signals:
     void newUpdate(const std::string &version) const;
+    void noNewUpdate() const;
 private:
     QTimer newUpdateTimer;
     QTimer firstUpdateTimer;
-    QNetworkAccessManager qnam;
+    QNetworkAccessManager *qnam;//destroy to close connection
     QNetworkReply *reply;
+
+    void downloadFileInternal(const bool force=false);
 private slots:
     void downloadFile();
     void httpFinished();
