@@ -17,9 +17,11 @@ public:
     explicit OSSpecific(QWidget *parent = 0);
     ~OSSpecific();
     bool dontShowAgain();
+    QString theme();
 private slots:
     void on_pushButton_clicked();
     void updateText();
+    void on_comboBox_currentIndexChanged(int index);
 protected slots:
     void changeEvent(QEvent *e);
 private:
