@@ -80,10 +80,8 @@ SystrayIcon::SystrayIcon(QObject * parent) :
     #ifdef ULTRACOPIER_DEBUG
     systrayMenu->addAction(actionSaveBugReport);
     #endif
-    #ifndef Q_OS_LINUX
-    if(!ProductKey::productKey->isUltimate())
+    if(!FacilityEngine::facilityEngine.ultimateUrl().empty())
         systrayMenu->addAction(actionProductKey);
-    #endif
     systrayMenu->addAction(actionMenuQuit);
     #ifndef Q_OS_MAC
     systrayMenu->insertSeparator(actionOptions);
@@ -452,7 +450,7 @@ void SystrayIcon::retranslateTheUI()
     #endif
     actionMenuQuit		->setText(tr("&Quit"));
     actionOptions		->setText(tr("&Options"));
-    actionProductKey		->setText(tr("&Product key"));
+    actionProductKey		->setText(tr("&Register product key"));
     reloadEngineList();
     updateSystrayIcon();
 }
