@@ -6,17 +6,17 @@
     <message>
         <location filename="../../OptionsWidget.ui" line="17"/>
         <source>In normal case, only the dll 64Bits is important with 64Bits OS, and 32Bits dll with 32Bits OS. When it&apos;s important, the UAC can be opened to load the dll.</source>
-        <translation>Solitamente, la dll 64Bit è indispensabile solo per sistemi operativi a 64Bit, e la dll 32Bit per sistemi operativi a 32Bits. Quando è necessario, l&apos; UAC (il controllo dell&apos;account utente) può essere aperto per caricare la dll.</translation>
+        <translation>Solitamente, le librerie dll 64bit sono indispensabili solo per sistemi operativi a x64, e le librerie 32bit per sistemi operativi a x86. Quando è necessario, l&apos; UAC (il controllo dell&apos;account utente) può essere aperto per caricare le dll</translation>
     </message>
     <message>
         <location filename="../../OptionsWidget.ui" line="20"/>
         <source>All the dlls are importants</source>
-        <translation>Tutte le dll sono necessarie</translation>
+        <translation>Tutte le librerie dll sono necessarie</translation>
     </message>
     <message>
         <location filename="../../OptionsWidget.ui" line="34"/>
         <source>Register for all users</source>
-        <translation type="unfinished"></translation>
+        <translation>Registrare per tutti gli utenti</translation>
     </message>
 </context>
 </TS>
