@@ -4,14 +4,19 @@
 <context>
     <name>Themes</name>
     <message>
-        <location filename="../../interface.cpp" line="+327"/>
+        <location filename="../../interface.cpp" line="+328"/>
         <source>Buy the Ultimate version to fund development</source>
+        <translation type="unfinished">개발 지원을 위해 Ultimate 버전 구입</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>Register your key</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+85"/>
+        <location line="+99"/>
         <source>File %1/%2, size: %3/%4</source>
-        <translation type="unfinished">파일 %1/%2, 크기: %3/%4</translation>
+        <translation type="unfinished">%1/%2 파일, 크기: %3/%4</translation>
     </message>
     <message>
         <location line="+234"/>
@@ -21,41 +26,41 @@
     <message>
         <location line="+2"/>
         <source>Move list</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">이동 목록</translation>
     </message>
     <message>
         <location line="+428"/>
         <source>Don&apos;t close if errors are found</source>
-        <translation type="unfinished">오류 발견시 종료 안함</translation>
+        <translation type="unfinished">오류가 발견될 경우 닫지 않음</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Never close</source>
-        <translation type="unfinished">절대 종료 안함</translation>
+        <translation type="unfinished">닫지 않음</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Always close</source>
-        <translation type="unfinished">항상 종료</translation>
+        <translation type="unfinished">항상 닫기</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>File Name, 0KB</source>
-        <translation type="unfinished">파일명, 0KB</translation>
+        <translation type="unfinished">파일 이름, 0KB</translation>
     </message>
     <message>
         <location line="+194"/>
         <location line="+12"/>
         <location line="+12"/>
         <source>Select a color</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">색상 선택</translation>
     </message>
     <message>
         <location line="+75"/>
         <location line="+4"/>
         <location line="+2"/>
         <source>%1 %2% of %3</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">%1: %3 중 %2%</translation>
     </message>
 </context>
 <context>
@@ -63,30 +68,30 @@
     <message>
         <location filename="../../ThemesFactory.cpp" line="+284"/>
         <source>Don&apos;t close if errors are found</source>
-        <translation type="unfinished">오류 발견시 종료 안함</translation>
+        <translation type="unfinished">오류가 발견된 경우 닫지 않음</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Never close</source>
-        <translation type="unfinished">절대 종료 안함</translation>
+        <translation type="unfinished">닫지 않음</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Always close</source>
-        <translation type="unfinished">항상 종료</translation>
+        <translation type="unfinished">항상 닫기</translation>
     </message>
     <message>
         <location line="+196"/>
         <location line="+15"/>
         <location line="+15"/>
         <source>Select a color</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">색상 선택</translation>
     </message>
 </context>
 <context>
     <name>interfaceCopy</name>
     <message>
-        <location filename="../../interface.ui" line="+35"/>
+        <location filename="../../interface.ui" line="+44"/>
         <source>From:</source>
         <translation type="unfinished">원본:</translation>
     </message>
@@ -103,7 +108,7 @@
     <message>
         <location line="+20"/>
         <source>&amp;Pause</source>
-        <translation type="unfinished">&amp;일시 정지</translation>
+        <translation type="unfinished">&amp;일시 중지</translation>
     </message>
     <message>
         <location line="+14"/>
@@ -118,22 +123,22 @@
     <message>
         <location line="+58"/>
         <source>Transfer list</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">전송 목록</translation>
     </message>
     <message>
         <location line="+156"/>
         <source>Delete the selected items</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">선택한 항목 삭제</translation>
     </message>
     <message>
         <location line="+55"/>
         <source>Export the transfer list</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">전송 목록 내보내기</translation>
     </message>
     <message>
         <location line="+26"/>
         <source>Import the transfer list</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">전송 목록 가져오기</translation>
     </message>
     <message>
         <location line="+55"/>
@@ -153,66 +158,66 @@
     <message>
         <location line="-389"/>
         <source>Move the selected items to the top</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">선택한 항목 맨 위로 이동</translation>
     </message>
     <message>
         <location line="-234"/>
         <source>Close on transfer completion</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">전송 완료 시 닫기</translation>
     </message>
     <message>
         <location line="+168"/>
         <source>Limit copy speed to:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">복사 속도 제한:</translation>
     </message>
     <message>
         <location line="+92"/>
         <source>Move up the selected items</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">선택한 항목 위로 이동</translation>
     </message>
     <message>
         <location line="+26"/>
         <source>Move down the selected items</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">선택한 항목 아래로 이동</translation>
     </message>
     <message>
         <location line="+26"/>
         <source>Move the selected items to the bottom</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">선택한 항목 맨 아래로 이동</translation>
     </message>
     <message>
         <location line="+26"/>
         <source>Add file/folder</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">파일/폴더 추가</translation>
     </message>
     <message>
         <location line="+55"/>
         <source>Search</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">검색</translation>
     </message>
     <message>
         <location line="+152"/>
         <location line="+69"/>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">오류</translation>
     </message>
     <message>
         <location line="-49"/>
         <source>Export the errors into transfer list</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">전송 목록에 오류 내보내기</translation>
     </message>
     <message>
         <location line="+39"/>
         <source>Source</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">원본</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Destination</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">대상</translation>
     </message>
     <message>
-        <location line="+51"/>
+        <location line="+60"/>
         <source>Add file</source>
         <translation type="unfinished">파일 추가</translation>
     </message>
@@ -247,48 +252,48 @@
     <message>
         <location filename="../../themesOptions.ui" line="+267"/>
         <source>Show dual progression</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">이중 진행 표시</translation>
     </message>
     <message>
         <location line="-48"/>
         <source>Show speed as main information</source>
-        <translation type="unfinished">메인 정보에 속도 표시</translation>
+        <translation type="unfinished">주요 정보로 속도 표시</translation>
     </message>
     <message>
         <location line="-175"/>
         <source>Use</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">사용</translation>
     </message>
     <message>
         <location line="+129"/>
         <source>Start with the &quot;more button&quot; pushed</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&quot;추가 버튼&quot;을 눌러 시작</translation>
     </message>
     <message>
         <location line="-106"/>
         <source>Minimize on close to systray</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">닫기 버튼을 누를 때 트레이로 최소화</translation>
     </message>
     <message>
         <location line="+29"/>
         <source>At the end of the copy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">복사 완료 시</translation>
     </message>
     <message>
         <location line="+7"/>
         <location line="+34"/>
         <source>Limit copy speed to</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">복사 속도 제한</translation>
     </message>
     <message>
         <location line="-84"/>
         <source>Start minimized</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">최소화된 시작</translation>
     </message>
     <message>
         <location line="+253"/>
         <source>Click to edit the color</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">색상 편집 클릭</translation>
     </message>
     <message>
         <location line="-159"/>
@@ -298,37 +303,37 @@
     <message>
         <location line="+43"/>
         <source>Save position</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">위치 저장</translation>
     </message>
     <message>
         <location line="+23"/>
         <source>Informations</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">정보</translation>
     </message>
     <message>
         <location line="+38"/>
         <source>Display</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">표시</translation>
     </message>
     <message>
         <location line="+6"/>
         <source>Speed with progress bar</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">진행 표시줄이 있는 속도</translation>
     </message>
     <message>
         <location line="+30"/>
         <source>Progression color</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">진행 색상</translation>
     </message>
     <message>
         <location line="-10"/>
         <source>Show progression in the title</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">제목에 진행률 표시</translation>
     </message>
     <message>
         <location line="-94"/>
         <source>Always on top</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">항상 위에 놓기</translation>
     </message>
 </context>
 </TS>
